@@ -43,6 +43,12 @@ def expected_calibration_error(prediction_probabilities, accuracy, confidence):
     been calculated for each point in the dataset and given in the array
     prediction_probabilities.
 
+    .. seealso::
+
+       `Examples using calibration <https://stellargraph.readthedocs.io/en/stable/demos/calibration/index.html>`__.
+
+       Related functionality: :func:`.plot_reliability_diagram`, :class:`.IsotonicCalibration`, :class:`.TemperatureCalibration`.
+
     Args:
         prediction_probabilities (numpy array):  The predicted probabilities.
         accuracy (numpy array): The accuracy such that the i-th entry in the array holds the proportion of correctly
@@ -95,9 +101,15 @@ def plot_reliability_diagram(calibration_data, predictions, ece=None, filename=N
     """
     Helper function for plotting a reliability diagram.
 
+    .. seealso::
+
+       `Examples using calibration <https://stellargraph.readthedocs.io/en/stable/demos/calibration/index.html>`__.
+
+       Related functionality: :func:`.expected_calibration_error`, :class:`.IsotonicCalibration`, :class:`.TemperatureCalibration`.
+
     Args:
         calibration_data (list): The calibration data as a list where each entry in the list is a 2-tuple of type
-            numpy.ndarray. Each entry in the tuple holds the fraction of positives and the mean predicted values
+            :class:`numpy.ndarray`. Each entry in the tuple holds the fraction of positives and the mean predicted values
             for the true and predicted class labels.
         predictions (np.ndarray): The probabilistic predictions of the classifier for each sample in the dataset used
             for diagnosing miscalibration.
@@ -169,6 +181,12 @@ class TemperatureCalibration(object):
     logits to calculate the probabilistic output. As noted in the cited paper, Temperature
     Scaling does not change the maximum of the softmax function so the classifier's prediction
     remain the same.
+
+    .. seealso::
+
+       `Examples using calibration <https://stellargraph.readthedocs.io/en/stable/demos/calibration/index.html>`__.
+
+       Related functionality: :func:`.expected_calibration_error`, :func:`.plot_reliability_diagram`, :class:`.IsotonicCalibration`.
     """
 
     def __init__(self, epochs=1000):
@@ -359,6 +377,12 @@ class TemperatureCalibration(object):
 class IsotonicCalibration(object):
     """
     A class for applying Isotonic Calibration to the outputs of a binary or multi-class classifier.
+
+    .. seealso::
+
+       `Examples using calibration <https://stellargraph.readthedocs.io/en/stable/demos/calibration/index.html>`__.
+
+       Related functionality: :func:`.expected_calibration_error`, :func:`.plot_reliability_diagram`, :class:`.TemperatureCalibration`.
     """
 
     def __init__(self):
@@ -371,7 +395,7 @@ class IsotonicCalibration(object):
 
         Args:
             x_train (numpy array): The training data that should be the classifier's probabilistic outputs. It should
-                have shape NxC where N is the number of training samples and C is the number of classes.
+                have shape N × C where N is the number of training samples and C is the number of classes.
             y_train (numpy array): The training class labels. For binary problems y_train has shape (N,)
                 when N is the number of samples. For multi-class classification, y_train has shape (N,C) where
                 C is the number of classes and y_train is using one-hot encoding.
