@@ -41,7 +41,12 @@ class Ensemble(object):
     Naive ensembles add model diversity by random initialisation of the models' weights (before training) to
     different values. Each model in the ensemble is trained on the same training set of examples.
 
-    """
+    .. seealso::
+
+       Example using ensembles: `node classification <https://stellargraph.readthedocs.io/en/stable/demos/ensembles/ensemble-node-classification-example.html>`__.
+
+       Related functionality: :class:`.BaggingEnsemble` for bootstrap sampling while training, in addition to random initialisation.
+   """
 
     def __init__(self, model, n_estimators=3, n_predictions=3):
         """
@@ -54,7 +59,7 @@ class Ensemble(object):
         if not isinstance(model, K.Model):
             raise ValueError(
                 "({}) model must be a Keras model received object of type {}".format(
-                    type(self).__name__, type(model)
+                    type(self).__name__, type(model).__name__
                 )
             )
         if n_estimators <= 0 or not isinstance(n_estimators, int):
@@ -101,7 +106,7 @@ class Ensemble(object):
 
     def layers(self, indx=None):
         """
-        This method returns the layer objects for the model specified by the value of indx.
+        This method returns the layer objects for the model specified by the value of ``indx``.
 
         Args:
             indx (None or int): The index  (starting at 0) of the model to return the layers for.
@@ -114,7 +119,7 @@ class Ensemble(object):
         if indx is not None and not isinstance(indx, (int,)):
             raise ValueError(
                 "({}) indx should be None or integer type but received type {}".format(
-                    type(self).__name__, type(indx)
+                    type(self).__name__, type(indx).__name__
                 )
             )
         if isinstance(indx, (int,)) and indx < 0:
@@ -156,7 +161,7 @@ class Ensemble(object):
 
         Args:
             optimizer (Keras optimizer or str): (Keras-specific parameter) The optimizer to use given either as an
-                instance of a keras optimizer or a string naming the optimiser of choice.
+                instance of a Keras optimizer or a string naming the optimiser of choice.
             loss (Keras function or str): (Keras-specific parameter) The loss function or string indicating the
                 type of loss to use.
             metrics (list or dict): (Keras-specific parameter) List of metrics to be evaluated by each model in
@@ -221,7 +226,7 @@ class Ensemble(object):
             steps_per_epoch (None or int): (Keras-specific parameter) If not None, it specifies the number of steps
                 to yield from the generator before declaring one epoch finished and starting a new epoch.
             epochs (int): (Keras-specific parameter) The number of training epochs.
-            verbose (int): (Keras-specific parameter) The verbocity mode that should be 0 , 1, or 2 meaning silent,
+            verbose (int): (Keras-specific parameter) The verbosity mode that should be 0 , 1, or 2 meaning silent,
                 progress bar, and one line per epoch respectively.
             validation_data: A generator for validation data that is optional (None). If not None then, it should
                 be one of type NodeSequence, LinkSequence, SparseFullBatchSequence, or FullBatchSequence.
@@ -259,7 +264,7 @@ class Ensemble(object):
             raise ValueError(
                 "({}) If train_data is None, generator must be one of type NodeSequence, LinkSequence, FullBatchSequence "
                 "but received object of type {}".format(
-                    type(self).__name__, type(generator)
+                    type(self).__name__, type(generator).__name__
                 )
             )
 
@@ -336,8 +341,8 @@ class Ensemble(object):
             max_queue_size (int): (Keras-specific parameter) The maximum size for the generator queue.
             workers (int): (Keras-specific parameter) The maximum number of workers to use.
             use_multiprocessing (bool): (Keras-specific parameter) If True then use process based threading.
-            verbose (int): (Keras-specific parameter) The verbocity mode that should be 0 or 1 with the former turning
-                verbocity off and the latter on.
+            verbose (int): (Keras-specific parameter) The verbosity mode that should be 0 or 1 with the former turning
+                verbosity off and the latter on.
 
         Returns:
             tuple: The mean and standard deviation of the model metrics for the given data.
@@ -356,7 +361,7 @@ class Ensemble(object):
             raise ValueError(
                 "({}) generator parameter must be of type GraphSAGENodeGenerator, HinSAGENodeGenerator, FullBatchNodeGenerator, "
                 "GraphSAGELinkGenerator, or HinSAGELinkGenerator. Received type {}".format(
-                    type(self).__name__, type(generator)
+                    type(self).__name__, type(generator).__name__
                 )
             )
         elif not isinstance(
@@ -372,7 +377,7 @@ class Ensemble(object):
                 "({}) If test_data is None, generator must be one of type NodeSequence, "
                 "LinkSequence, FullBatchSequence, or SparseFullBatchSequence "
                 "but received object of type {}".format(
-                    type(self).__name__, type(generator)
+                    type(self).__name__, type(generator).__name__
                 )
             )
         if test_data is not None and test_targets is None:
@@ -445,14 +450,14 @@ class Ensemble(object):
             max_queue_size (int): (Keras-specific parameter) The maximum size for the generator queue.
             workers (int): (Keras-specific parameter) The maximum number of workers to use.
             use_multiprocessing (bool): (Keras-specific parameter) If True then use process based threading.
-            verbose (int): (Keras-specific parameter) The verbocity mode that should be 0 or 1 with the former turning
-                verbocity off and the latter on.
+            verbose (int): (Keras-specific parameter) The verbosity mode that should be 0 or 1 with the former turning
+                verbosity off and the latter on.
 
 
         Returns:
-            numpy array: The predictions. It will have shape `MxKxNxF` if **summarise** is set to `False`, or NxF
-            otherwise. `M` is the number of estimators in the ensemble; `K` is the number of predictions per query
-            point; `N` is the number of query points; and `F` is the output dimensionality of the specified layer
+            numpy array: The predictions. It will have shape ``M × K × N × F`` if ``summarise`` is set to ``False``, or ``N × F``
+            otherwise. ``M`` is the number of estimators in the ensemble; ``K`` is the number of predictions per query
+            point; ``N`` is the number of query points; and ``F`` is the output dimensionality of the specified layer
             determined by the shape of the output layer.
 
         """
@@ -468,7 +473,7 @@ class Ensemble(object):
             ):
                 raise ValueError(
                     "({}) generator parameter must be of type GraphSAGENodeGenerator, HinSAGENodeGenerator, or FullBatchNodeGenerator. Received type {}".format(
-                        type(self).__name__, type(generator)
+                        type(self).__name__, type(generator).__name__
                     )
                 )
             data_generator = generator.flow(predict_data)
@@ -551,6 +556,12 @@ class BaggingEnsemble(Ensemble):
     training) to different values; and (2) by bootstrap sampling of the training data for each model. That is, each
     model in the ensemble is trained on a random subset of the training examples, sampled with replacement from the
     original training data.
+
+    .. seealso::
+
+       `Examples using ensembles <https://stellargraph.readthedocs.io/en/stable/demos/ensembles/index.html>`__.
+
+       Related functionality: :class:`.Ensemble` for only random initialisation.
     """
 
     def __init__(self, model, n_estimators=3, n_predictions=3):
@@ -611,7 +622,7 @@ class BaggingEnsemble(Ensemble):
             steps_per_epoch (None or int): (Keras-specific parameter) If not None, it specifies the number of steps
                 to yield from the generator before declaring one epoch finished and starting a new epoch.
             epochs (int): (Keras-specific parameter) The number of training epochs.
-            verbose (int): (Keras-specific parameter) The verbocity mode that should be 0 , 1, or 2 meaning silent,
+            verbose (int): (Keras-specific parameter) The verbosity mode that should be 0 , 1, or 2 meaning silent,
                 progress bar, and one line per epoch respectively.
             validation_data: A generator for validation data that is optional (None). If not None then, it should
                 be one of type GraphSAGENodeGenerator, HinSAGENodeGenerator, FullBatchNodeGenerator,
@@ -653,7 +664,7 @@ class BaggingEnsemble(Ensemble):
             raise ValueError(
                 "({}) generator parameter must be of type GraphSAGENodeGenerator, HinSAGENodeGenerator, "
                 "FullBatchNodeGenerator, GraphSAGELinkGenerator, or HinSAGELinkGenerator if you want to use Bagging. "
-                "Received type {}".format(type(self).__name__, type(generator))
+                "Received type {}".format(type(self).__name__, type(generator).__name__)
             )
         if bag_size is not None and (bag_size > len(train_data) or bag_size <= 0):
             raise ValueError(
