@@ -31,6 +31,7 @@ from .appnp import *
 from .gcn import *
 from .cluster_gcn import *
 from .attri2vec import *
+from .node2vec import *
 from .misc import SqueezedSparseConversion
 from .preprocessing_layer import GraphPreProcessingLayer
 from .rgcn import *
@@ -38,3 +39,5 @@ from .watch_your_step import *
 from .knowledge_graph import *
 from .graph_classification import *
 from .deep_graph_infomax import *
+from .sort_pooling import *
+from .gcn_lstm import *
