@@ -279,7 +279,7 @@ class GraphSAGEAggregator(Layer):
         Assumes that the layer will be built to match that input shape provided.
 
         Args:
-            input_shape (tuple of ints)
+            input_shape (tuple of int)
                 Shape tuples can include None for free dimensions, instead of an integer.
 
         Returns:
@@ -297,7 +297,7 @@ class GraphSAGEAggregator(Layer):
             group_idx (int, optional): Group index.
 
         Returns:
-            [tf.Tensor]: A tensor aggregation of the input nodes features.
+            :class:`tensorflow.Tensor`: A tensor aggregation of the input nodes features.
         """
         raise NotImplementedError(
             "The GraphSAGEAggregator base class should not be directly instantiated"
@@ -325,7 +325,7 @@ class MeanAggregator(GraphSAGEAggregator):
             group_idx (int, optional): Group index.
 
         Returns:
-            tf.Tensor: A tensor aggregation of the input nodes features.
+            :class:`tensorflow.Tensor`: A tensor aggregation of the input nodes features.
         """
         # The first group is assumed to be the self-tensor and we do not aggregate over it
         if group_idx == 0:
@@ -413,7 +413,7 @@ class MaxPoolingAggregator(GraphSAGEAggregator):
             group_idx (int, optional): Group index.
 
         Returns:
-            tf.Tensor: A tensor aggregation of the input nodes features.
+            :class:`tensorflow.Tensor`: A tensor aggregation of the input nodes features.
         """
         if group_idx == 0:
             # Do not aggregate features for head nodes
@@ -510,7 +510,7 @@ class MeanPoolingAggregator(GraphSAGEAggregator):
             group_idx (int, optional): Group index.
 
         Returns:
-            [tf.Tensor]: A tensor aggregation of the input nodes features.
+            :class:`tensorflow.Tensor`: A tensor aggregation of the input nodes features.
         """
         if group_idx == 0:
             # Do not aggregate features for head nodes
@@ -612,7 +612,7 @@ class AttentionalAggregator(GraphSAGEAggregator):
             * self.weight_sizes: the size of the output from this group.
 
         The AttentionalAggregator is implemented to not use the first (head node) group. This makes
-        the implmentation different from other aggregators.
+        the implementation different from other aggregators.
 
         Args:
             input_shape (list of list of int): Shape of input tensors for self
@@ -728,22 +728,22 @@ class GraphSAGE:
     Implementation of the GraphSAGE algorithm of Hamilton et al. with Keras layers.
     see: http://snap.stanford.edu/graphsage/
 
-    The model minimally requires specification of the layer sizes as a list of ints
+    The model minimally requires specification of the layer sizes as a list of int
     corresponding to the feature dimensions for each hidden layer and a generator object.
 
     Different neighbour node aggregators can also be specified with the ``aggregator``
     argument, which should be the aggregator class,
-    either :class:`MeanAggregator`, :class:`MeanPoolingAggregator`,
-    :class:`MaxPoolingAggregator`, or :class:`AttentionalAggregator`.
+    either :class:`.MeanAggregator`, :class:`.MeanPoolingAggregator`,
+    :class:`.MaxPoolingAggregator`, or :class:`.AttentionalAggregator`.
 
     To use this class as a Keras model, the features and graph should be supplied using the
-    :class:`GraphSAGENodeGenerator` class for node inference models or the
-    :class:`GraphSAGELinkGenerator` class for link inference models.  The `.in_out_tensors` method should
+    :class:`.GraphSAGENodeGenerator` class for node inference models or the
+    :class:`.GraphSAGELinkGenerator` class for link inference models.  The `.in_out_tensors` method should
     be used to create a Keras model from the `GraphSAGE` object.
 
     Examples:
         Creating a two-level GrapSAGE node classification model with hidden node sizes of 8 and 4
-        and 10 neighbours sampled at each layer using an existing :class:`StellarGraph` object `G`
+        and 10 neighbours sampled at each layer using an existing :class:`.StellarGraph` object `G`
         containing the graph and node features::
 
             generator = GraphSAGENodeGenerator(G, batch_size=50, num_samples=[10,10])
@@ -757,8 +757,26 @@ class GraphSAGE:
     Note that passing a `NodeSequence` or `LinkSequence` object from the `generator.flow(...)` method
     as the `generator=` argument is now deprecated and the base generator object should be passed instead.
 
-    For more details, please see `the GraphSAGE demo notebooks
-    <https://stellargraph.readthedocs.io/en/stable/demos/node-classification/graphsage-node-classification.html>`_.
+    .. seealso::
+
+       Examples using GraphSAGE:
+
+       - node classification: `natively <https://stellargraph.readthedocs.io/en/stable/demos/node-classification/graphsage-node-classification.html>`__, `via Neo4j <https://stellargraph.readthedocs.io/en/stable/demos/connector/neo4j/undirected-graphsage-on-cora-neo4j-example.html>`__
+       - `link prediction <https://stellargraph.readthedocs.io/en/stable/demos/link-prediction/graphsage-link-prediction.html>`__
+       - unsupervised representation learning: `via random walks <https://stellargraph.readthedocs.io/en/stable/demos/embeddings/graphsage-unsupervised-sampler-embeddings.html>`__, `via Deep Graph Infomax <https://stellargraph.readthedocs.io/en/stable/demos/embeddings/deep-graph-infomax-embeddings.html>`__
+       - calibrating models: `node classification <https://stellargraph.readthedocs.io/en/stable/demos/calibration/calibration-node-classification.html>`__, `link prediction <https://stellargraph.readthedocs.io/en/stable/demos/calibration/calibration-link-prediction.html>`__
+       - ensemble models: `node classification <https://stellargraph.readthedocs.io/en/stable/demos/ensembles/ensemble-node-classification-example.html>`__, `link prediction <https://stellargraph.readthedocs.io/en/stable/demos/ensembles/ensemble-link-prediction-example.html>`__
+       - `comparison of link prediction algorithms <https://stellargraph.readthedocs.io/en/stable/demos/link-prediction/homogeneous-comparison-link-prediction.html>`__
+
+       Appropriate data generators: :class:`.GraphSAGENodeGenerator`, :class:`.Neo4jGraphSAGENodeGenerator`, :class:`.GraphSAGELinkGenerator`.
+
+       Related models:
+
+       - :class:`.DirectedGraphSAGE` for a generalisation to directed graphs
+       - :class:`.HinSAGE` for a generalisation to heterogeneous graphs
+       - :class:`.DeepGraphInfomax` for unsupervised training
+
+       Aggregators: :class:`.MeanAggregator`, :class:`.MeanPoolingAggregator`, :class:`.MaxPoolingAggregator`, :class:`.AttentionalAggregator`.
 
     Args:
         layer_sizes (list): Hidden feature dimensions for each layer.
@@ -769,7 +787,7 @@ class GraphSAGE:
         dropout (float): The dropout supplied to each layer; defaults to no dropout.
         normalize (str or None): The normalization used after each layer; defaults to L2 normalization.
         activations (list): Activations applied to each layer's output;
-            defaults to ['relu', ..., 'relu', 'linear'].
+            defaults to ``['relu', ..., 'relu', 'linear']``.
         kernel_initializer (str or func, optional): The initialiser to use for the weights of each layer.
         kernel_regularizer (str or func, optional): The regulariser to use for the weights of each layer.
         kernel_constraint (str or func, optional): The constraint to use for the weights of each layer.
@@ -1045,9 +1063,9 @@ class GraphSAGE:
         the model (whether it is a node or link/node pair generator).
 
         Returns:
-            tuple: (x_inp, x_out), where ``x_inp`` is a list of Keras input tensors
-            for the specified GraphSAGE model (either node or link/node pair model) and ``x_out`` contains
-            model output tensor(s) of shape (batch_size, layer_sizes[-1])
+            tuple: ``(x_inp, x_out)``, where ``x_inp`` is a list of Keras input tensors
+                for the specified GraphSAGE model (either node or link/node pair model) and ``x_out`` contains
+                model output tensor(s) of shape (batch_size, layer_sizes[-1])
 
         """
         if multiplicity is None:
@@ -1081,13 +1099,29 @@ class DirectedGraphSAGE(GraphSAGE):
     Implementation of a directed version of the GraphSAGE algorithm of Hamilton et al. with Keras layers.
     see: http://snap.stanford.edu/graphsage/
 
-    The model minimally requires specification of the layer sizes as a list of ints
+    The model minimally requires specification of the layer sizes as a list of int
     corresponding to the feature dimensions for each hidden layer and a generator object.
 
     Different neighbour node aggregators can also be specified with the ``aggregator``
     argument, which should be the aggregator class,
-    either :class:`MeanAggregator`, :class:`MeanPoolingAggregator`,
-    :class:`MaxPoolingAggregator`, or :class:`AttentionalAggregator`.
+    either :class:`.MeanAggregator`, :class:`.MeanPoolingAggregator`,
+    :class:`.MaxPoolingAggregator`, or :class:`.AttentionalAggregator`.
+
+    .. seealso::
+
+       Examples using Directed GraphSAGE:
+
+       - `node classification <https://stellargraph.readthedocs.io/en/stable/demos/node-classification/directed-graphsage-node-classification.html>`__
+       - `node classification with Neo4j <https://stellargraph.readthedocs.io/en/stable/demos/connector/neo4j/directed-graphsage-on-cora-neo4j-example.html>`__
+
+       Appropriate data generators: :class:`.DirectedGraphSAGENodeGenerator`, :class:`.Neo4jDirectedGraphSAGENodeGenerator`, :class:`.DirectedGraphSAGELinkGenerator`.
+
+       Related models:
+
+       - :class:`.GraphSAGE` for undirected graphs
+       - :class:`.HinSAGE` for undirected heterogeneous graphs
+
+       Aggregators: :class:`.MeanAggregator`, :class:`.MeanPoolingAggregator`, :class:`.MaxPoolingAggregator`, :class:`.AttentionalAggregator`.
 
     Args:
         layer_sizes (list): Hidden feature dimensions for each layer.
