@@ -25,7 +25,7 @@ class PaddedGraphGenerator(Generator):
     """
     A data generator for use with graph classification algorithms.
 
-    The supplied graphs should be :class:`StellarGraph` objects with node features.
+    The supplied graphs should be :class:`.StellarGraph` objects with node features.
     Use the :meth:`flow` method supplying the graph indexes and (optionally) targets
     to get an object that can be used as a Keras data generator.
 
@@ -34,6 +34,16 @@ class PaddedGraphGenerator(Generator):
     batch of features and adjacency matrices, and supplying a boolean mask indicating which are
     valid and which are padding.
 
+    .. seealso::
+
+       Models using this generator: :class:`.GCNSupervisedGraphClassification`, :class:`.DeepGraphCNN`.
+
+       Examples using this generator:
+
+       - `graph classification with GCN <https://stellargraph.readthedocs.io/en/stable/demos/graph-classification/gcn-supervised-graph-classification.html>`__
+       - `graph classification with Deep Graph CNN <https://stellargraph.readthedocs.io/en/stable/demos/graph-classification/dgcnn-graph-classification.html>`__
+       - `unsupervised graph representation learning <https://stellargraph.readthedocs.io/en/stable/demos/embeddings/gcn-unsupervised-graph-embeddings.html>`__
+
     Args:
         graphs (list): a collection of StellarGraph objects
         name (str): an optional name of the generator
@@ -97,7 +107,7 @@ class PaddedGraphGenerator(Generator):
         with the supplied graph indexes and targets.
 
         Args:
-            graphs (iterable): an iterable of graph indexes in self.graphs or an iterable of :class:`StellarGraph` objects
+            graphs (iterable): an iterable of graph indexes in self.graphs or an iterable of :class:`.StellarGraph` objects
                 for the graphs of interest (e.g., training, validation, or test set nodes).
             targets (2d array, optional): a 2D array of numeric graph targets with shape ``(len(graphs),
                 len(targets))``.
@@ -113,7 +123,7 @@ class PaddedGraphGenerator(Generator):
             seed (int, optional): Random seed to use in the sequence object.
 
         Returns:
-            A :class:`PaddedGraphSequence` object to use with Keras methods :meth:`fit`, :meth:`evaluate`, and :meth:`predict`
+            A :class:`.PaddedGraphSequence` object to use with Keras methods :meth:`fit`, :meth:`evaluate`, and :meth:`predict`
 
         """
         if targets is not None:
@@ -179,7 +189,7 @@ class PaddedGraphSequence(Sequence):
         :meth:`keras.Model.predict`,
 
     This class should be created using the `.flow(...)` method of
-    :class:`PaddedGraphGenerator`.
+    :class:`.PaddedGraphGenerator`.
 
     Args:
         graphs (list)): The graphs as StellarGraph objects.
