@@ -195,19 +195,40 @@ class GraphSAGENodeGenerator(BatchedNodeGenerator):
         train_data_gen = G_generator.flow(train_node_ids, train_node_labels)
         test_data_gen = G_generator.flow(test_node_ids)
 
+    .. seealso::
+
+       Model using this generator: :class:`.GraphSAGE`.
+
+       Some examples using this generator (see the model for more):
+
+       - `node classification <https://stellargraph.readthedocs.io/en/stable/demos/node-classification/graphsage-node-classification.html>`__
+       - `unsupervised representation learning via Deep Graph Infomax <https://stellargraph.readthedocs.io/en/stable/demos/embeddings/deep-graph-infomax-embeddings.html>`__
+
+       Related functionality:
+
+       - :class:`.Neo4jGraphSAGENodeGenerator` for using :class:`.GraphSAGE` with Neo4j
+       - :class:`.CorruptedGenerator` for unsupervised training using :class:`.DeepGraphInfomax`
+       - :class:`.GraphSAGELinkGenerator` for link prediction, unsupervised training using random walks and related tasks
+       - :class:`.DirectedGraphSAGENodeGenerator` for directed graphs
+       - :class:`.HinSAGENodeGenerator` for heterogeneous graphs
+
     Args:
         G (StellarGraph): The machine-learning ready graph.
         batch_size (int): Size of batch to return.
         num_samples (list): The number of samples per layer (hop) to take.
         seed (int): [Optional] Random seed for the node sampler.
+        weighted (bool, optional): If True, sample neighbours using the edge weights in the graph.
     """
 
-    def __init__(self, G, batch_size, num_samples, seed=None, name=None):
+    def __init__(
+        self, G, batch_size, num_samples, seed=None, name=None, weighted=False
+    ):
         super().__init__(G, batch_size)
 
         self.num_samples = num_samples
         self.head_node_types = self.schema.node_types
         self.name = name
+        self.weighted = weighted
 
         # Check that there is only a single node type for GraphSAGE
         if len(self.head_node_types) > 1:
@@ -237,11 +258,11 @@ class GraphSAGENodeGenerator(BatchedNodeGenerator):
             A list of the same length as ``num_samples`` of collected features from
             the sampled nodes of shape:
             ``(len(head_nodes), num_sampled_at_layer, feature_size)``
-            where num_sampled_at_layer is the cumulative product of `num_samples`
+            where ``num_sampled_at_layer`` is the cumulative product of ``num_samples``
             for that layer.
         """
         node_samples = self._samplers[batch_num].run(
-            nodes=head_nodes, n=1, n_size=self.num_samples
+            nodes=head_nodes, n=1, n_size=self.num_samples, weighted=self.weighted
         )
 
         # The number of samples for each head node (not including itself)
@@ -298,15 +319,39 @@ class DirectedGraphSAGENodeGenerator(BatchedNodeGenerator):
         train_data_gen = G_generator.flow(train_node_ids, train_node_labels)
         test_data_gen = G_generator.flow(test_node_ids)
 
+    .. seealso::
+
+       Model using this generator: :class:`.DirectedGraphSAGE`.
+
+       Example using this generator: `node classification <https://stellargraph.readthedocs.io/en/stable/demos/node-classification/directed-graphsage-node-classification.html>`__.
+
+       Related functionality:
+
+       - :class:`.Neo4jDirectedGraphSAGENodeGenerator` for using :class:`.DirectedGraphSAGE` with Neo4j
+       - :class:`.CorruptedGenerator` for unsupervised training using :class:`.DeepGraphInfomax`
+       - :class:`.DirectedGraphSAGELinkGenerator` for link prediction and related tasks
+       - :class:`.GraphSAGENodeGenerator` for undirected graphs
+       - :class:`.HinSAGENodeGenerator` for heterogeneous graphs
+
     Args:
         G (StellarDiGraph): The machine-learning ready graph.
         batch_size (int): Size of batch to return.
         in_samples (list): The number of in-node samples per layer (hop) to take.
         out_samples (list): The number of out-node samples per layer (hop) to take.
         seed (int): [Optional] Random seed for the node sampler.
+        weighted (bool, optional): If True, sample neighbours using the edge weights in the graph.
     """
 
-    def __init__(self, G, batch_size, in_samples, out_samples, seed=None, name=None):
+    def __init__(
+        self,
+        G,
+        batch_size,
+        in_samples,
+        out_samples,
+        seed=None,
+        name=None,
+        weighted=False,
+    ):
         super().__init__(G, batch_size)
 
         # TODO Add checks for in- and out-nodes sizes
@@ -314,6 +359,7 @@ class DirectedGraphSAGENodeGenerator(BatchedNodeGenerator):
         self.out_samples = out_samples
         self.head_node_types = self.schema.node_types
         self.name = name
+        self.weighted = weighted
 
         # Check that there is only a single node type for GraphSAGE
         if len(self.head_node_types) > 1:
@@ -345,12 +391,16 @@ class DirectedGraphSAGENodeGenerator(BatchedNodeGenerator):
         Returns:
             A list of feature tensors from the sampled nodes at each layer, each of shape:
             ``(len(head_nodes), num_sampled_at_layer, feature_size)``
-            where num_sampled_at_layer is the total number (cumulative product)
+            where ``num_sampled_at_layer`` is the total number (cumulative product)
             of nodes sampled at the given number of hops from each head node,
             given the sequence of in/out directions.
         """
         node_samples = self.sampler.run(
-            nodes=head_nodes, n=1, in_size=self.in_samples, out_size=self.out_samples
+            nodes=head_nodes,
+            n=1,
+            in_size=self.in_samples,
+            out_size=self.out_samples,
+            weighted=self.weighted,
         )
 
         # Reshape node samples to sensible format
@@ -394,6 +444,19 @@ class HinSAGENodeGenerator(BatchedNodeGenerator):
     Note that the shuffle argument should be True for training and
     False for prediction.
 
+    .. seealso::
+
+       Model using this generator: :class:`.HinSAGE`.
+
+       Example using this generator: `unsupervised representation learning via Deep Graph Infomax <https://stellargraph.readthedocs.io/en/stable/demos/embeddings/deep-graph-infomax-embeddings.html>`_.
+
+       Related functionality:
+
+       - :class:`.CorruptedGenerator` for unsupervised training using :class:`.DeepGraphInfomax`
+       - :class:`.HinSAGELinkGenerator` for link prediction and related tasks
+       - :class:`.GraphSAGENodeGenerator` for homogeneous graphs
+       - :class:`.DirectedGraphSAGENodeGenerator` for directed homogeneous graphs
+
     Args:
         G (StellarGraph): The machine-learning ready graph
         batch_size (int): Size of batch to return
@@ -465,7 +528,7 @@ class HinSAGENodeGenerator(BatchedNodeGenerator):
             A list of the same length as ``num_samples`` of collected features from
             the sampled nodes of shape:
             ``(len(head_nodes), num_sampled_at_layer, feature_size)``
-            where num_sampled_at_layer is the cumulative product of `num_samples`
+            where ``num_sampled_at_layer`` is the cumulative product of ``num_samples``
             for that layer.
         """
         # Get sampled nodes
@@ -527,6 +590,14 @@ class Attri2VecNodeGenerator(BatchedNodeGenerator):
         G_generator = Attri2VecNodeGenerator(G, 50)
         data_gen = G_generator.flow(node_ids)
 
+    .. seealso::
+
+       Model using this generator: :class:`.Attri2Vec`.
+
+       An example using this generator (see the model for more): `node classification <https://stellargraph.readthedocs.io/en/stable/demos/node-classification/attri2vec-node-classification.html>`__.
+
+       Related functionality: :class:`.Attri2VecLinkGenerator` for training, link prediction and related tasks.
+
     Args:
         G (StellarGraph): The machine-learning ready graph.
         batch_size (int): Size of batch to return.
@@ -613,6 +684,14 @@ class Node2VecNodeGenerator(BatchedNodeGenerator):
         G_generator = Node2VecNodeGenerator(G, 50)
         data_gen = G_generator.flow(node_ids)
 
+    .. seealso::
+
+       Model using this generator: :class:`.Node2Vec`.
+
+       An example using this generator (see the model for more): `unsupervised representation learning <https://stellargraph.readthedocs.io/en/stable/demos/embeddings/keras-node2vec-embeddings.html>`_.
+
+       Related functionality: :class:`.Node2VecLinkGenerator` for training, link prediction, and related tasks.
+
     Args:
         G (StellarGraph): The machine-learning ready graph.
         batch_size (int): Size of batch to return.
