@@ -20,3 +20,5 @@ This contains the utility objects used by the StellarGraph library.
 """
 
 from .history import *
+from .version_validation import *
+from . import hyperbolic
