@@ -15,9 +15,17 @@
 # limitations under the License.
 
 import pandas as pd
+import numpy as np
 import pytest
 from stellargraph.data.explorer import SampledHeterogeneousBreadthFirstWalk
 from stellargraph.core.graph import StellarGraph
+from ..test_utils.graphs import example_graph_random
+
+
+def _recursive_items_equal(arr1, arr2):
+    for y1, y2 in zip(arr1, arr2):
+        for x1, x2 in zip(y1, y2):
+            return (set(x1) == set(x2)) and (len(x1) == len(x2))
 
 
 # FIXME (#535): Consider using graph fixtures. These two test graphs are very similar, and should be combined
@@ -119,14 +127,18 @@ class TestSampledHeterogeneousBreadthFirstWalk(object):
         g = create_test_graph(self_loop=True)
         bfw = SampledHeterogeneousBreadthFirstWalk(g)
 
-        nodes = [0]  # this is an isolated user node with no self loop
+        nodes = g.node_ids_to_ilocs(
+            [0]
+        )  # this is an isolated user node with no self loop
         n = 1
         n_size = [0]
 
         subgraphs = bfw.run(nodes=nodes, n=n, n_size=n_size)
         assert len(subgraphs) == 1
         assert len(subgraphs[0]) == 3
-        assert subgraphs[0][0][0] == 0  # this should be the root node id
+        assert (
+            subgraphs[0][0][0] == g.node_ids_to_ilocs([0])[0]
+        )  # this should be the root node id
         # node 0 is of type 'user' and for the simple test graph it has 2 types of edges, rating, and friend,
         # so 2 empty subgraphs should be returned
         assert len(subgraphs[0][1]) == 0  # this should be empty list
@@ -139,30 +151,30 @@ class TestSampledHeterogeneousBreadthFirstWalk(object):
         assert (
             len(subgraphs[0]) == 9
         )  # we return all fake samples in walk even if there are no neighbours
-        assert subgraphs[0][0][0] == 0  # this should be the root node id
+        assert (
+            subgraphs[0][0][0] == g.node_ids_to_ilocs([0])[0]
+        )  # this should be the root node id
 
         # node 0 is of type 'user' and for the simple test graph it has 2 types of edges, rating, and friend,
         # so 2 subgraphs with None should be returned
         assert len(subgraphs[0][1]) == 2
-        assert all([x is None for x in subgraphs[0][1]])  # this should only be None
+        assert all([x == -1 for x in subgraphs[0][1]])  # this should only be None
         assert len(subgraphs[0][2]) == 2
-        assert all([x is None for x in subgraphs[0][2]])  # this should only be None
+        assert all([x == -1 for x in subgraphs[0][2]])  # this should only be None
 
     def test_walk_generation_single_root_node_self_loner(self):
         g = create_test_graph(self_loop=True)
         bfw = SampledHeterogeneousBreadthFirstWalk(g)
 
-        root_node_id = 7
-        nodes = [
-            root_node_id
-        ]  # this node is only connected with itself with an edge of type "friend"
+        # this node is only connected with itself with an edge of type "friend"
+        nodes = g.node_ids_to_ilocs([7])
         n = 1
 
         n_size = [0]
         subgraphs = bfw.run(nodes=nodes, n=n, n_size=n_size)
         assert len(subgraphs) == 1
         assert len(subgraphs[0]) == 3
-        assert subgraphs[0][0][0] == root_node_id  # this should be the root node id
+        assert subgraphs[0][0][0] == nodes[0]  # this should be the root node id
         # node 0 is of type 'user' and for the simple test graph it has 2 types of edges, rating, and friend,
         # so 2 empty subgraphs should be returned
         assert len(subgraphs[0][1]) == 0  # this should be empty list
@@ -172,13 +184,13 @@ class TestSampledHeterogeneousBreadthFirstWalk(object):
         subgraphs = bfw.run(nodes=nodes, n=n, n_size=n_size)
         assert len(subgraphs) == 1
         assert len(subgraphs[0]) == 3
-        assert subgraphs[0][0][0] == root_node_id  # this should be the root node id
+        assert subgraphs[0][0][0] == nodes[0]  # this should be the root node id
 
         # node 0 is of type 'user' and for the simple test graph it has 2 types of edges, rating, and friend,
         # so 1 subgraph with the root id corresponding to friend type edge and 1 subgraph with None should be returned
-        assert subgraphs[0][1][0] == root_node_id  # this should be the root node id
+        assert subgraphs[0][1][0] == nodes[0]  # this should be the root node id
         assert len(subgraphs[0][2]) == 1  # this should be None
-        assert subgraphs[0][2] == [None]  # this should be None
+        assert subgraphs[0][2] == [-1]  # this should be None
 
         n_size = [2, 2]
         subgraphs = bfw.run(nodes=nodes, n=n, n_size=n_size)
@@ -191,7 +203,7 @@ class TestSampledHeterogeneousBreadthFirstWalk(object):
             if len(level) > 0:
                 # All values should be rood_node_id or None
                 for value in level:
-                    assert (value == root_node_id) or (value is None)
+                    assert (value == nodes[0]) or (value == -1)
 
         n_size = [2, 2, 3]
         subgraphs2 = bfw.run(nodes=nodes, n=n, n_size=n_size)
@@ -210,36 +222,42 @@ class TestSampledHeterogeneousBreadthFirstWalk(object):
             assert type(level) == list
             if len(level) > 0:
                 for value in level:
-                    assert (value == root_node_id) or (value is None)
+                    assert (value == nodes[0]) or (value == -1)
 
     def test_walk_generation_single_root_node(self):
 
         g = create_test_graph(self_loop=True)
         bfw = SampledHeterogeneousBreadthFirstWalk(g)
 
-        nodes = [3]
+        def _conv(ns):
+            return [-1 if n is None else g.node_ids_to_ilocs([n])[0] for n in ns]
+
+        nodes = _conv([3])
         n = 1
         n_size = [2]
 
         subgraphs = bfw.run(nodes=nodes, n=n, n_size=n_size, seed=42)
         assert len(subgraphs) == n
-        assert subgraphs == [[[3], ["5", 1]]]
+        valid_result = [[_conv([3]), _conv(["5", 1])]]
+        assert _recursive_items_equal(subgraphs, valid_result)
 
         n_size = [3]
         subgraphs = bfw.run(nodes=nodes, n=n, n_size=n_size, seed=42)
         assert len(subgraphs) == n
-        assert subgraphs == [[[3], ["5", 1, 1]]]
+        valid_result = [[_conv([3]), _conv(["5", 1, 1])]]
+        assert _recursive_items_equal(subgraphs, valid_result)
 
         n_size = [1, 1]
         subgraphs = bfw.run(nodes=nodes, n=n, n_size=n_size, seed=42)
         assert len(subgraphs) == n
-        assert subgraphs == [[[3], ["5"], [1], [3]]]
+        valid_result = [[_conv([3]), _conv(["5"]), _conv([1]), _conv([3])]]
+        assert _recursive_items_equal(subgraphs, valid_result)
 
-        nodes = ["5"]
+        nodes = _conv(["5"])
         n_size = [2, 3]
         subgraphs = bfw.run(nodes=nodes, n=n, n_size=n_size, seed=42)
         assert len(subgraphs) == n
-        assert subgraphs == [
+        valid_result = [
             [
                 ["5"],
                 [4, 1],
@@ -252,8 +270,10 @@ class TestSampledHeterogeneousBreadthFirstWalk(object):
                 [1, "5", "5"],
             ]
         ]
+        valid_result = [[_conv(x) for x in y] for y in valid_result]
+        assert _recursive_items_equal(subgraphs, valid_result)
 
-        nodes = ["5"]
+        nodes = _conv(["5"])
         n_size = [2, 3]
         n = 3
         subgraphs = bfw.run(nodes=nodes, n=n, n_size=n_size, seed=42)
@@ -293,22 +313,25 @@ class TestSampledHeterogeneousBreadthFirstWalk(object):
                 ["5", "5", "5"],
             ],
         ]
-        for a, b in zip(subgraphs, valid_result):
-            assert len(a) == len(b)
-            assert a == b
+        valid_result = [[_conv(x) for x in y] for y in valid_result]
+
+        assert _recursive_items_equal(subgraphs, valid_result)
         #
         # Test with multi-graph
         #
         g = create_test_graph(multi=True)
         bfw = SampledHeterogeneousBreadthFirstWalk(g)
 
-        nodes = [1]
+        nodes = _conv([1])
         n = 1
         n_size = [2]
 
         subgraphs = bfw.run(nodes=nodes, n=n, n_size=n_size, seed=19893839)
         assert len(subgraphs) == n
-        assert subgraphs == [[[1], [4, 4], [4, 4], [2, 2]]]
+
+        valid_result = [[[1], [4, 4], [4, 4], [2, 2]]]
+        valid_result = [[_conv(x) for x in y] for y in valid_result]
+        _recursive_items_equal(subgraphs, valid_result)
 
         n_size = [2, 3]
         subgraphs = bfw.run(nodes=nodes, n=n, n_size=n_size, seed=19893839)
@@ -317,7 +340,7 @@ class TestSampledHeterogeneousBreadthFirstWalk(object):
             [
                 [1],
                 [4, 4],
-                [4, 4],
+                ["5", "5"],
                 [2, 2],
                 [1, 1, 1],
                 ["5", 1, 1],
@@ -325,46 +348,26 @@ class TestSampledHeterogeneousBreadthFirstWalk(object):
                 [1, 1, 1],
                 [1, "5", 1],
                 [2, 2, 2],
-                [1, 1, 1],
-                ["5", 1, "5"],
-                [2, 2, 2],
-                [1, 1, 1],
-                ["5", "5", 1],
-                [2, 2, 2],
+                [7, 7, 7],
                 [4, 1, 1],
-                [4, 1, 4],
+                [6, 3, 6],
+                [7, 7, 7],
+                [1, 4, 1],
+                [6, 6, 6],
+                [4, 1, 1],
+                [1, 1, 1],
             ]
         ]
-        for a, b in zip(subgraphs, valid_result):
-            assert len(a) == len(b)
-            assert a == b
 
-        nodes = [1]
+        valid_result = [[_conv(x) for x in y] for y in valid_result]
+        assert _recursive_items_equal(subgraphs, valid_result)
+
+        nodes = _conv([1])
         n_size = [2, 0]
         n = 2
         subgraphs = bfw.run(nodes=nodes, n=n, n_size=n_size, seed=19893839)
         assert len(subgraphs) == n
         valid_result = [
-            [
-                [1],
-                [4, 4],
-                [4, 4],
-                [2, 2],
-                [],
-                [],
-                [],
-                [],
-                [],
-                [],
-                [],
-                [],
-                [],
-                [],
-                [],
-                [],
-                [],
-                [],
-            ],
             [
                 [1],
                 [4, 4],
@@ -385,17 +388,39 @@ class TestSampledHeterogeneousBreadthFirstWalk(object):
                 [],
                 [],
             ],
+            [
+                [1],
+                [4, 4],
+                [4, 4],
+                [2, 2],
+                [],
+                [],
+                [],
+                [],
+                [],
+                [],
+                [],
+                [],
+                [],
+                [],
+                [],
+                [],
+                [],
+                [],
+            ],
         ]
-        for a, b in zip(subgraphs, valid_result):
-            assert len(a) == len(b)
-            assert a == b
+        valid_result = [[_conv(x) for x in y] for y in valid_result]
+        assert _recursive_items_equal(subgraphs, valid_result)
 
     def test_walk_generation_many_root_nodes(self):
 
         g = create_test_graph(self_loop=True)
         bfw = SampledHeterogeneousBreadthFirstWalk(g)
 
-        nodes = [0, 7]  # both nodes are type user
+        def _conv(ns):
+            return [-1 if n is None else g.node_ids_to_ilocs([n])[0] for n in ns]
+
+        nodes = _conv([0, 7])  # both nodes are type user
         n = 1
         n_size = [0]
 
@@ -417,12 +442,14 @@ class TestSampledHeterogeneousBreadthFirstWalk(object):
         for i, subgraph in enumerate(subgraphs):
             assert len(subgraph) == 3
 
-        valid_result = [[[0], [None, None], [None, None]], [[7], [7, 7], [None, None]]]
-        for a, b in zip(subgraphs, valid_result):
-            assert a == b
+        valid_result = [
+            [_conv([0]), [-1, -1], [-1, -1]],
+            [_conv([7]), _conv([7, 7]), [-1, -1]],
+        ]
+        assert _recursive_items_equal(valid_result, subgraphs)
 
         n_size = [2, 2]
-        nodes = [0, 4]
+        nodes = _conv([0, 4])
         subgraphs = bfw.run(nodes=nodes, n=n, n_size=n_size, seed=999)
         assert len(subgraphs) == len(nodes) * n
         assert subgraphs[0][0][0] == nodes[0]
@@ -438,13 +465,13 @@ class TestSampledHeterogeneousBreadthFirstWalk(object):
                 [None, None],
                 [None, None],
             ],
-            [[4], ["5", 1], [2, 2], [1, 1], [6, 3], ["5", "5"], [2, 3], [1, 1], [4, 4]],
+            [[4], ["5", 1], [2, 2], [1, 1], [6, 3], [4, 4], [2, 3], [1, 1], [4, 4]],
         ]
-        for a, b in zip(subgraphs, valid_result):
-            assert a == b
+        valid_result = [[_conv(x) for x in y] for y in valid_result]
+        assert _recursive_items_equal(subgraphs, valid_result)
 
         n_size = [2, 3]
-        nodes = [1, 6]  # a user and a movie node respectively
+        nodes = _conv([1, 6])  # a user and a movie node respectively
         subgraphs = bfw.run(nodes=nodes, n=n, n_size=n_size, seed=999)
         assert len(subgraphs) == len(nodes) * n
         assert subgraphs[0][0][0] == nodes[0]
@@ -453,17 +480,18 @@ class TestSampledHeterogeneousBreadthFirstWalk(object):
                 [1],
                 ["5", 4],
                 [3, 3],
-                [1, 1, 4],
-                [3, 6, 6],
-                [1, "5", 1],
+                [1, 1, "5"],
                 [2, 2, 2],
+                [1, 4, 1],
+                [3, 6, 6],
                 [1, "5", "5"],
                 [1, "5", 1],
             ],
             [[6], ["5", "5"], [4, 4, 1], [6, 3, 6], [4, 4, 1], [6, 6, 3]],
         ]
-        for a, b in zip(subgraphs, valid_result):
-            assert a == b
+
+        valid_result = [[_conv(x) for x in y] for y in valid_result]
+        assert _recursive_items_equal(subgraphs, valid_result)
 
         n = 5
         subgraphs = bfw.run(nodes=nodes, n=n, n_size=n_size, seed=999)
@@ -475,14 +503,16 @@ class TestSampledHeterogeneousBreadthFirstWalk(object):
         g = create_test_graph(multi=True)
         bfw = SampledHeterogeneousBreadthFirstWalk(g)
 
-        nodes = [1, 6]
+        nodes = _conv([1, 6])
         n = 1
         n_size = [2]
 
         subgraphs = bfw.run(nodes=nodes, n=n, n_size=n_size, seed=999)
         assert len(subgraphs) == n * len(nodes)
-        valid_result = [[[1], [4, 4], ["5", "5"], [2, 2]], [[6], ["5", "5"]]]
-        assert subgraphs == valid_result
+        valid_result = [[[1], [4, 4], [4, 4], [2, 2]], [[6], ["5", "5"]]]
+        valid_result = [[_conv(x) for x in y] for y in valid_result]
+
+        assert _recursive_items_equal(subgraphs, valid_result)
 
         n = 1
         n_size = [2, 3]
@@ -490,7 +520,7 @@ class TestSampledHeterogeneousBreadthFirstWalk(object):
         subgraphs = bfw.run(nodes=nodes, n=n, n_size=n_size, seed=999)
         assert len(subgraphs) == n * len(nodes)
 
-        nodes = [4, "5", 0]
+        nodes = _conv([4, "5", 0])
         n = 1
         n_size = [3, 3, 1]
 
@@ -502,11 +532,10 @@ class TestSampledHeterogeneousBreadthFirstWalk(object):
         assert len(subgraphs) == n * len(nodes)
 
     def test_benchmark_sampledheterogeneousbreadthfirstwalk(self, benchmark):
-
-        g = create_test_graph(self_loop=True)
+        g = example_graph_random(n_nodes=50, n_edges=250, node_types=2, edge_types=2)
         bfw = SampledHeterogeneousBreadthFirstWalk(g)
 
-        nodes = [0]
+        nodes = np.arange(0, 50)
         n = 5
         n_size = [5, 5]
 
