@@ -14,6 +14,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import sys
 import numpy as np
 from stellargraph.layer.rgcn import RelationalGraphConvolution, RGCN
 from stellargraph.mapper.full_batch_generators import RelationalFullBatchNodeGenerator
@@ -30,6 +31,7 @@ import pandas as pd
 from ..test_utils.graphs import (
     relational_create_graph_features as create_graph_features,
 )
+from .. import test_utils
 
 
 def test_RelationalGraphConvolution_config():
@@ -78,17 +80,17 @@ def test_RelationalGraphConvolution_init():
     assert rgcn_layer.get_config()["activation"] == "relu"
 
 
+@pytest.mark.xfail(sys.platform == "win32", reason="FIXME #1699")
 def test_RelationalGraphConvolution_sparse():
     G, features = create_graph_features()
-    n_edge_types = len(get_edge_types(G))
+    n_edge_types = len(G.edge_types)
 
     # We need to specify the batch shape as one for the GraphConvolutional logic to work
     n_nodes = features.shape[0]
     n_feat = features.shape[1]
 
-    # Inputs for features & target indices
+    # Inputs for features
     x_t = Input(batch_shape=(1, n_nodes, n_feat))
-    out_indices_t = Input(batch_shape=(1, None), dtype="int32")
 
     # Create inputs for sparse or dense matrices
 
@@ -99,7 +101,6 @@ def test_RelationalGraphConvolution_sparse():
     As_values = [Input(batch_shape=(1, None)) for i in range(n_edge_types)]
     A_placeholders = As_indices + As_values
 
-    # Test with final_layer=False
     Ainput = [
         SqueezedSparseConversion(shape=(n_nodes, n_nodes), dtype=As_values[i].dtype)(
             [As_indices[i], As_values[i]]
@@ -107,18 +108,17 @@ def test_RelationalGraphConvolution_sparse():
         for i in range(n_edge_types)
     ]
 
-    x_inp_model = [x_t, out_indices_t] + A_placeholders
-    x_inp_conv = [x_t, out_indices_t] + Ainput
+    x_inp_model = [x_t] + A_placeholders
+    x_inp_conv = [x_t] + Ainput
 
-    out = RelationalGraphConvolution(
-        2, num_relationships=n_edge_types, final_layer=False
-    )(x_inp_conv)
+    out = RelationalGraphConvolution(2, num_relationships=n_edge_types)(x_inp_conv)
 
     # Note we add a batch dimension of 1 to model inputs
     As = [A.tocoo() for A in get_As(G)]
 
     A_indices = [
-        np.expand_dims(np.hstack((A.row[:, None], A.col[:, None])), 0) for A in As
+        np.expand_dims(np.hstack((A.row[:, None], A.col[:, None])).astype(np.int64), 0)
+        for A in As
     ]
     A_values = [np.expand_dims(A.data, 0) for A in As]
 
@@ -126,22 +126,14 @@ def test_RelationalGraphConvolution_sparse():
     x = features[None, :, :]
 
     model = keras.Model(inputs=x_inp_model, outputs=out)
-    preds = model.predict([x, out_indices] + A_indices + A_values, batch_size=1)
+    preds = model.predict([x] + A_indices + A_values, batch_size=1)
     assert preds.shape == (1, 3, 2)
 
-    # Now try with final_layer=True
-    out = RelationalGraphConvolution(
-        2, num_relationships=n_edge_types, final_layer=True
-    )(x_inp_conv)
-    model = keras.Model(inputs=x_inp_model, outputs=out)
-    preds = model.predict([x, out_indices] + A_indices + A_values, batch_size=1)
-    assert preds.shape == (1, 2, 2)
-
 
 def test_RelationalGraphConvolution_dense():
 
     G, features = create_graph_features()
-    n_edge_types = len(get_edge_types(G))
+    n_edge_types = len(G.edge_types)
 
     # We need to specify the batch shape as one for the GraphConvolutional logic to work
     n_nodes = features.shape[0]
@@ -160,12 +152,10 @@ def test_RelationalGraphConvolution_dense():
 
     A_in = [Lambda(lambda A: K.squeeze(A, 0))(A_p) for A_p in A_placeholders]
 
-    x_inp_model = [x_t, out_indices_t] + A_placeholders
-    x_inp_conv = [x_t, out_indices_t] + A_in
+    x_inp_model = [x_t] + A_placeholders
+    x_inp_conv = [x_t] + A_in
 
-    out = RelationalGraphConvolution(
-        2, num_relationships=n_edge_types, final_layer=False
-    )(x_inp_conv)
+    out = RelationalGraphConvolution(2, num_relationships=n_edge_types)(x_inp_conv)
 
     As = [np.expand_dims(A.todense(), 0) for A in get_As(G)]
 
@@ -173,17 +163,9 @@ def test_RelationalGraphConvolution_dense():
     x = features[None, :, :]
 
     model = keras.Model(inputs=x_inp_model, outputs=out)
-    preds = model.predict([x, out_indices] + As, batch_size=1)
+    preds = model.predict([x] + As, batch_size=1)
     assert preds.shape == (1, 3, 2)
 
-    # Now try with final_layer=True
-    out = RelationalGraphConvolution(
-        2, num_relationships=n_edge_types, final_layer=True
-    )(x_inp_conv)
-    model = keras.Model(inputs=x_inp_model, outputs=out)
-    preds = model.predict([x, out_indices] + As, batch_size=1)
-    assert preds.shape == (1, 2, 2)
-
 
 def test_RGCN_init():
     G, features = create_graph_features()
@@ -197,13 +179,15 @@ def test_RGCN_init():
     assert rgcnModel.num_bases == 10
 
 
+@pytest.mark.xfail(sys.platform == "win32", reason="FIXME #1699")
 def test_RGCN_apply_sparse():
-    G, features = create_graph_features()
+    G, features = create_graph_features(is_directed=True)
 
     As = get_As(G)
     As = [A.tocoo() for A in As]
     A_indices = [
-        np.expand_dims(np.hstack((A.row[:, None], A.col[:, None])), 0) for A in As
+        np.expand_dims(np.hstack((A.row[:, None], A.col[:, None])).astype(np.int64), 0)
+        for A in As
     ]
     A_values = [np.expand_dims(A.data, 0) for A in As]
 
@@ -226,7 +210,7 @@ def test_RGCN_apply_sparse():
 
 
 def test_RGCN_apply_dense():
-    G, features = create_graph_features()
+    G, features = create_graph_features(is_directed=True)
 
     As = get_As(G)
     As = [np.expand_dims(A.todense(), 0) for A in As]
@@ -249,6 +233,7 @@ def test_RGCN_apply_dense():
     assert preds_1 == pytest.approx(preds_2)
 
 
+@pytest.mark.xfail(sys.platform == "win32", reason="FIXME #1699")
 def test_RGCN_apply_sparse_directed():
     G, features = create_graph_features(is_directed=True)
 
@@ -256,7 +241,8 @@ def test_RGCN_apply_sparse_directed():
     As = [A.tocoo() for A in As]
 
     A_indices = [
-        np.expand_dims(np.hstack((A.row[:, None], A.col[:, None])), 0) for A in As
+        np.expand_dims(np.hstack((A.row[:, None], A.col[:, None])).astype(np.int64), 0)
+        for A in As
     ]
     A_values = [np.expand_dims(A.data, 0) for A in As]
 
@@ -350,18 +336,13 @@ def test_RelationalGraphConvolution_edge_cases():
     assert str(error) == "units should be positive"
 
 
-def get_edge_types(G):
-    assert isinstance(G, StellarGraph)
-    return sorted(set(etype for _, _, etype in G.edges(include_edge_type=True)))
-
-
 def get_As(G):
 
     As = []
-    edge_types = get_edge_types(G)
     node_list = list(G.nodes())
     node_index = dict(zip(node_list, range(len(node_list))))
-    for edge_type in edge_types:
+
+    for edge_type in G.edge_types:
         col_index = [
             node_index[n1]
             for n1, n2, etype in G.edges(include_edge_type=True)
@@ -397,3 +378,14 @@ def test_kernel_and_bias_defaults():
             assert layer.bias_regularizer is None
             assert layer.kernel_constraint is None
             assert layer.bias_constraint is None
+
+
+@pytest.mark.parametrize("num_bases", [0, 10])
+@pytest.mark.parametrize(
+    "sparse", [False, pytest.param(True, marks=pytest.mark.xfail(reason="FIXME #1251"))]
+)
+def test_RGCN_save_load(tmpdir, num_bases, sparse):
+    graph, _ = create_graph_features()
+    generator = RelationalFullBatchNodeGenerator(graph, sparse=sparse)
+    rgcn = RGCN([2, 2], generator, num_bases=num_bases)
+    test_utils.model_save_load(tmpdir, rgcn)
